.. image:: https://img.shields.io/pypi/v/lsl-relay.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/lsl-relay.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/lsl-relay

.. image:: https://github.com/pupil-labs/lsl-relay/workflows/tests/badge.svg
   :target: https://github.com/pupil-labs/lsl-relay/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. image:: https://readthedocs.org/projects/lsl-relay/badge/?version=latest
   :target: https://lsl-relay.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/skeleton-2022-informational
   :target: https://blog.jaraco.com/skeleton

*************************************************
Pupil Labs LSL Relay for Pupil Invisible
*************************************************

- `Documentation <https://pupil-labs-lsl-relay.readthedocs.io>`_
- Note: `the Neon Companion app now supports LSL by default <https://docs.pupil-labs.com/neon/data-collection/lab-streaming-layer/>`_. Using the LSL Relay with Neon is now deprecated.
